package com.tencent.liteav.demo.superplayer.util;

import java.util.Timer;
import java.util.TimerTask;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;

public class CountDownUtil {
    // 倒计时的监听者
    public interface OnTickListener {
        void onTimeout(CountDownUtil util);
    }

    public static CountDownUtil build(long period, long maxCount, CountDownUtil.OnTickListener listener) {
        return new CountDownUtil(period, maxCount, listener);
    }

    public static final int STATE_INIT = 0;
    public static final int STATE_RUNNING = 0;
    public static final int STATE_PAUSE = 0;
    public static final int STATE_CANCEL = 0;

    private int state = STATE_INIT;

    // 周期时间
    private final long period;

    // 定时数
    private final long maxCount;

    // 回调监听对象
    private final CountDownUtil.OnTickListener listener;

    // 计时器
    private final Timer timer = new Timer();

    // 计时任务
    private TimerTask task;

    // 计数器
    private final AtomicLong count = new AtomicLong(0L);

    private CountDownUtil(long period, long maxCount, CountDownUtil.OnTickListener listener) {
        this.period = period;
        this.maxCount = maxCount;
        this.listener = listener;
    }

    public void startOrResume() {
        if (STATE_INIT == state) {
            state = STATE_RUNNING;
            count.set(0);
            setupTask();
        }else{
            if (STATE_PAUSE == state) {
                state = STATE_RUNNING;
                setupTask();
            }
        }

    }

    public void pause() {
        if (STATE_RUNNING == state) {
            state = STATE_PAUSE;

            if (task != null) {
                task.cancel();
                timer.purge();
                task = null;
            }
        }
    }

    public void cancel() {
        state = STATE_CANCEL;
        timer.cancel();
    }

    private void setupTask() {
        task = new TimerTask() {
            @Override
            public void run() {
                count.addAndGet(1);

                if (count.get() >= maxCount) {
                    listener.onTimeout(CountDownUtil.this);
                }
            }
        };

        timer.schedule(task, 0, period);
    }
}
